Spiffs

Struct Spiffs 

pub struct Spiffs { /* private fields */ }
Represents a Spiffs filesystem.

Implementations

Source

impl Spiffs

pub unsafe fn new(partition_label: &str) -> Result<Self, EspError>

Create a new - readonly - FAT filesystem instance for a given raw partition in the internal flash. This API is unsafe because currently esp-idf-svc does not have a safe way to represent a flash partition.

Arguments
  • Spiffs partition label.
Safety

While the filesystem object is alive, the partition should not be modified elsewhere

pub fn partition_label(&self) -> &CStr

Get the partition label.

pub fn check(&mut self) -> Result<(), EspError>

Check the filesystem for errors.

pub fn format(&mut self) -> Result<(), EspError>

Format the partition.

pub fn gc(&mut self, size_to_gc: usize) -> Result<(), EspError>

Garbage collect the filesystem.