pub struct Spiffs { /* private fields */ }Expand description
Represents a Spiffs filesystem.
Implementations
Sourceimpl Spiffs
impl Spiffs
Sourcepub unsafe fn new(partition_label: &str) -> Result<Self, EspError>
pub unsafe fn new(partition_label: &str) -> Result<Self, EspError>
Create a new - readonly - FAT filesystem instance for a given raw partition in the internal flash.
This API is unsafe because currently esp-idf-svc does not have a safe way to
represent a flash partition.
Arguments
- Spiffs partition label.
Safety
While the filesystem object is alive, the partition should not be modified elsewhere
Sourcepub fn partition_label(&self) -> &CStr
pub fn partition_label(&self) -> &CStr
Get the partition label.